#
# Name: hp_qla2x00.spec
# Copyright: (c)2004 Hewlett-Packard Company
#
# Description: spec file for hp_qla2x00 RPM

Name: hp_qla2x00
Version: 8.00.00
Release: 17 
Summary: HP QLA HBA Driver
Source: hp_qla2x00.tar.gz
Vendor: Hewlett-Packard
Copyright: proprietary
Group: System/Kernel
BuildRoot: %{_builddir}/hp_qla2x00

%undefine __check_files

%description
Loads the HP supported QLogic HBA driver.

%build

# set defines

SRCDIR="/usr/src/linux"
DRIVERVERSION="qla2xxx-8.00.00"
DRVSRCDIR=$RPM_BUILD_DIR/hp_qla2x00/$DRIVERVERSION
OBJDIR="/usr/src/linux-obj"

# untar source files

rm -fr $RPM_BUILD_DIR/hp_qla2x00
gunzip $RPM_SOURCE_DIR/hp_qla2x00.tar.gz
tar xvf $RPM_SOURCE_DIR/hp_qla2x00.tar

# build driver

# check to see if source directory exists

if test ! -d $DRVSRCDIR
then
 echo "Cannot find $DRVSRCDIR"
 exit 1
fi

# check to make sure that the kernel source directory is there

if test ! -d $SRCDIR
then
 echo "Cannot find $SRCDIR"
 exit 1
fi

# check to see if precompiled object headers exits

if test ! -d $OBJDIR
then
 echo "Cannot find $OBJDIR"
 exit 1
fi

# get architecture

if [ "`uname -m`" = "i386" ] || [ "`uname -m`" = "i486" ] || [ "`uname -m`" = "i586" ] || [ "`uname -m`" = "i686" ]
then
 ARCH=i386
elif [ "`uname -m`" = "ia64" ]
then
 ARCH=ia64
elif [ "`uname -m`" = "x86_64" ]
then
 ARCH=x86_64
else
 echo "Cannot determine architecture, exiting"
 exit 1
fi

# determine kernel type

KERNTYPE=`uname -r  | awk 'BEGIN {FS="-"} {if ($4 == "") print $3; else print $3"-"$4}'`

if [ "$KERNTYPE" = "" ]
then
 echo "Could not determine kernel subtype"
 exit 1
fi

# go to driver source code directory

cd $DRVSRCDIR

# make clean

make -C $SRCDIR M=`pwd` clean
if [ $? -ne 0 ]
then
 echo ""
 echo "Make clean failed!"
 exit 1
fi

# compile driver

make -C $SRCDIR O=${OBJDIR}/${ARCH}/${KERNTYPE} M=`pwd` modules

if [ $? -ne 0 ]
then
 echo ""
 echo "Driver build failed!"
 exit 1
fi

%install

OPTDIR=opt/hp/hp_qla2x00
DRIVERVERSION="qla2xxx-8.00.00"
LIBDIR="usr/lib"

# copy opt directory files

mkdir -p $RPM_BUILD_ROOT/$OPTDIR
cp $RPM_BUILD_ROOT/$DRIVERVERSION/qla2300.ko $RPM_BUILD_ROOT/$OPTDIR/qla2300.ko
cp $RPM_BUILD_ROOT/$DRIVERVERSION/qla6312.ko $RPM_BUILD_ROOT/$OPTDIR/qla6312.ko
cp $RPM_BUILD_ROOT/$DRIVERVERSION/qla2xxx.ko $RPM_BUILD_ROOT/$OPTDIR/qla2xxx.ko
cp $RPM_BUILD_ROOT/set_parm $RPM_BUILD_ROOT/$OPTDIR/set_parm
cp $RPM_BUILD_ROOT/set_parm2 $RPM_BUILD_ROOT/$OPTDIR/set_parm2
cp $RPM_BUILD_ROOT/edit_conf $RPM_BUILD_ROOT/$OPTDIR/edit_conf
cp $RPM_BUILD_ROOT/make_initrd $RPM_BUILD_ROOT/$OPTDIR/make_initrd
cp $RPM_BUILD_ROOT/README $RPM_BUILD_ROOT/$OPTDIR/README
cp $RPM_BUILD_ROOT/readme.libqlsdm $RPM_BUILD_ROOT/$OPTDIR/readme.libqlsdm
cp $RPM_BUILD_ROOT/scsi_patch_sles9.bin $RPM_BUILD_ROOT/$OPTDIR/scsi_patch_sles9.bin

# copy /etc files

mkdir -p $RPM_BUILD_ROOT/etc
touch $RPM_BUILD_ROOT/etc/.hp_pkinstall

# copy qlsdm library based on architecture

mkdir -p $RPM_BUILD_ROOT/$LIBDIR

if [ "`uname -m`" = "i386" ] || [ "`uname -m`" = "i486" ] || [ "`uname -m`" = "i586" ] || [ "`uname -m`" = "i686" ] ||[ "`uname -m`" = "x86_64" ]
then
 cp $RPM_BUILD_ROOT/libqlsdm-ia32.so $RPM_BUILD_ROOT/$LIBDIR/libqlsdm.so
elif [ "`uname -m`" = "ia64" ]
then
 cp $RPM_BUILD_ROOT/libqlsdm-ia64.so $RPM_BUILD_ROOT/$LIBDIR/libqlsdm.so
fi

%files

%attr (644,root,root)	/opt/hp/hp_qla2x00/qla2300.ko
%attr (644,root,root)	/opt/hp/hp_qla2x00/qla6312.ko
%attr (644,root,root)	/opt/hp/hp_qla2x00/qla2xxx.ko
%attr (744,root,root)	/opt/hp/hp_qla2x00/edit_conf
%attr (744,root,root)	/opt/hp/hp_qla2x00/make_initrd
%attr (744,root,root)	/opt/hp/hp_qla2x00/set_parm
%attr (744,root,root)	/opt/hp/hp_qla2x00/set_parm2
%attr (444,root,root)	/opt/hp/hp_qla2x00/README
%attr (444,root,root)	/opt/hp/hp_qla2x00/readme.libqlsdm
%attr (744,root,root)	/opt/hp/hp_qla2x00/scsi_patch_sles9.bin
%attr (444,root,root)	/etc/.hp_pkinstall
%attr (755,root,root)	/usr/lib/libqlsdm.so

%clean

rm -fr $RPM_BUILD_DIR/hp_qla2x00
gzip $RPM_SOURCE_DIR/hp_qla2x00.tar

%changelog
* Tue Oct 19 2004 Chad Dupuis <chad.dupuis@hp.com>

- Changed set_parm to recognize new default values

  Port Down Retry Count = 30
  Login Retry Count = 30

* Thu Oct 06 2004 Chad Dupuis <chad.dupuis@hp.com>

- Added 8.00.00 driver sources

* Fri Sep 24 2004 Chad Dupuis <chad.dupuis@hp.com>

- Added 8.00.00b17-hp sources which fix the following
  bugs
     bus reset issue
     EVA failover issue

* Thu Sep 23 2004 Chad Dupuis <chad.dupuis@hp.com>

- Added scsi_patch.bin to apply correct HSV110
  entry in scsi_devinfo.c

* Tue Sep 21 2004 Chad Dupuis <chad.dupuis@hp.com>

- Added 8.00.00b17 driver sources with EVA failover
  patch

* Thu Sep 09 2004 Chad Dupuis <chad.dupuis@hp.com>

- Use /usr/src/linux/README.SUSE to identify OS
  in edit_conf instead of /etc/issue

* Tue Aug 30 2004 Chad Dupuis <chad.dupuis@hp.com>

- Added 8.00.00b20 driver sources

* Mon Aug 30 2004 Chad Dupuis <chad.dupuis@hp.com>

- Added 8.00.00b19 driver sources
- Changed default PDRC for failover configs to 3
- Added ia64 libqlsdm library

* Wed Aug 25 2004 Chad Dupuis <chad.dupuis@hp.com>

- Added 8.00.00b18 driver sources

* Tue Aug 17 2004 Chad Dupuis <chad.dupuis@hp.com>

- Added new make_initrd

* Mon Aug 16 2004 Chad Dupuis <chad.dupuis@hp.com>

- Detect whether a loaded driver is using failover
  or nonfailover mode

* Fri Aug 6 2004 Chad Dupuis <chad.dupuis@hp.com>

- Added libqlsdm library for x86, x86_64 architectures
- Added code to modify /etc/hba.conf
- Added 8.00.00b17 driver sources

* Wed Jul 21 2004 Chad Dupuis <chad.dupuis@hp.com>

- Added support for the qla6312 (QLA200) module

* Mon Jul 19 2004 Chad Dupuis <chad.dupuis@hp.com>

- Added 8.00.00b16 driver sources

* Tue Jun 29 2004 Chad Dupuis <chad.dupuis@hp.com>

- Added 8.00.00b14 sources

* Thu Jun 24 2004 Chad Dupuis <chad.dupuis@hp.com>

- Fixed make_initrd to only build an initrd for
  the current running kernel on SUSE distributions

* Tue Jun 15 2004 Chad Dupuis <chad.dupuis@hp.com>

- Initial development

%pre

# make sure we are installing on a 2.4 kernel

KERNVER=`uname -r | cut -c 1-3`

if [ "$KERNVER" != "2.6" ]
then
 echo ""
 echo "This machine is not running a 2.6 kernel!"
 echo ""
 exit 1
fi

%post

SRCDIR=/opt/hp/hp_qla2x00
MODULELIST="qla2xxx.ko qla2300.ko qla6312.ko"
MODDIR=/lib/modules/`uname -r`/kernel/drivers/scsi/qla2xxx

# create hp_qla2x00.conf if needed

ls /etc/hp_qla2x00.conf 1>/dev/null 2>/dev/null

if [ $? -ne 0 ]
then
 # determine if a driver already loaded in memory is in failover mode
 # or single path mode.  If no driver is loade default to single path

 if test -d /proc/scsi/qla2xxx
 then
        FOMODE=`more /proc/scsi/qla2xxx/* | grep "Driver version" | grep fo`

        # use set_parm2 to write out the correct settings

        if [ "$FOMODE" = "" ]
        then
                echo "Loaded driver is in nonfailover mode"
                $SRCDIR/set_parm2 -s
        else
                echo "Loaded driver is in failover mode"
                $SRCDIR/set_parm2 -x
        fi
 else
        # no driver loaded, so default to failover mode

        echo "No driver loaded, using failover mode"
        $SRCDIR/set_parm2 -x
 fi
else
 echo "/etc/hp_qla2x00.conf already exists.  Using parameters in the current file."
fi

# Modify /etc/hba.conf

if [ -f "/etc/hba.conf" ]
then
 # file exists, see if we need to make the edit

 if [ `grep -c qla2x00 /etc/hba.conf` -eq 0 ]
 then
 	echo "Modifying /etc/hba.conf"
	echo "qla2xxx	/usr/lib/libqlsdm.so" >> /etc/hba.conf
 fi
else
 # file does not exist, create it

 echo "Modifying /etc/hba.conf"
 echo "qla2xxx	/usr/lib/libqlsdm.so" > /etc/hba.conf
 chown root:root /etc/hba.conf
 chmod 644 /etc/hba.conf
fi 

cd $SRCDIR

# copy new modules 

for i in $MODULELIST
do
 # save old modules
 echo "Saving old $i"
 mv -f $MODDIR/$i $MODDIR/$i.old
 
 # copy new modules
 echo "Copying $i to $MODDIR"
 cp $i $MODDIR/$i
done

# run depmod

echo "Running depmod -a"
depmod -a

# edit configuration files

echo ""
./edit_conf

# create new initrd

echo ""
./make_initrd

echo ""
echo "Utility files are located in $SRCDIR"

%postun

if test ! -f /etc/.hp_pkinstall
then
 # we are removing the package, so uninstall everything

 MODULEDIR=/lib/modules/`uname -r`/kernel/drivers/scsi/qla2xxx
 MODLIST="qla2300.ko qla6312.ko qla2xxx.ko"
 MODCONF=/etc/modprobe.conf.local
 SRCDIR="/opt/hp/hp_qla2x00"
 
 # remove /etc/hp_qla2x00.conf

 echo "Removing /etc/hp_qla2x00.conf"
 rm -f /etc/hp_qla2x00.conf

 # remove reference from /etc/hba.conf to qla2x00

 echo "Removing reference to qla2xxx from /etc/hba.conf"
 cat /etc/hba.conf | grep -v qla2xxx > /tmp/hba.conf
 mv /etc/hba.conf /etc/hba.conf.old
 mv /tmp/hba.conf /etc/hba.conf
 chmod 644 /etc/hba.conf
 chown root:root /etc/hba.conf

 # remove stuff from /etc/modprobe.conf.local

 echo "Removing parameters from $MODCONF"
 cat $MODCONF | grep -v "options qla2xxx" > $MODCONF.new
 mv -f $MODCONF $MODCONF.old
 mv -f $MODCONF.new $MODCONF
 chmod 644 $MODCONF
 chown root:root $MODCONF

 # remove modules and restore old ones

 for i in $MODLIST
 do
 	if test -a $MODULEDIR/$i
 	then
 		echo "Removing $MODULEDIR/$i"
 		rm -f $MODULEDIR/$i
 	fi

 	if test -a $MODULEDIR/$i.old
 	then
		echo "Restoring old $i"
		mv -f $MODULEDIR/$i.old $MODULEDIR/$i
 	fi
 done

 # run depmod -a

 echo "Running depmod -a"
 depmod -a

 # remove /opt/hp/hp_qla2x00

 echo "Removing $SRCDIR"
 
 cd $SRCDIR
 
 if [ $? -eq 0 ]
 then
 	rm -f *
 	cd ../
 	rmdir $SRCDIR
 fi

 echo ""
 echo "Your initrd has not been updated.  You will have to do that manually."
else
 # if this is an upgrade, don't remove anything

 echo -n "" # no-op
fi

exit 0

