#!/bin/bash
#
# Name: master.sh
# Copyright: (c)2004 Hewlett-Packard
#
# Description: master build script for 2.6 drivers
#
# Chad Dupuis 05/26/04 Initial Development
# Chad Dupuis 06/03/04 Added ability of accept command line
#                      parameters to select which kernel and
#                      source directory we are going to use

#
# function defs
#

# list the source and module directories that are available
# on this system

list_sm_dir () {
 echo "Kernel source directories available:"
 echo "" 
 ls /usr/src | grep linux | grep -v obj | paste -
 echo ""
 echo "Kernel module directories available:"
 echo ""
 ls /lib/modules | grep "2.6" | paste -
}

# prints command line help

print_help () {
 echo "Usage: $0 [-lh -s source_directory -m module_directory ]"
 echo ""
 echo "-l: lists the available kernel source and module directories"
 echo "-s: kernel source directory to use"
 echo "-m: kernel module directory to use"
 echo "-h: prints help"
 echo ""
 echo "example: $0 -s linux-2.4.21-9.EL -m 2.4.21-9.ELsmp"
}

#
# Script Main
#

# only process arguments if we have any

if [ $# -gt 0 ]
then
 USEARGS=1

 # command line flag

 LISTFLAG=0 
 SOURCEFLAG=0
 MODULEFLAG=0
 HELPFLAG=0

 # parse command line into arguments

 getopt lm:s:h $* 1>/dev/null 2>/dev/null

 # check result of parsing

 if [ $? != 0 ]
 then
 	echo "Bad argument or missing argument"
 	exit 1
 fi

 set -- `getopt lm:s:h $*`

 while [ $1 != -- ]
 do
 	case $1 in
		-l) LISTFLAG=1;;
		-m) MODULEFLAG=1
		    MODULEDIR=$2
		    shift;;
		-s) SOURCEFLAG=1
		    SOURCEDIR=$2
		    shift;;
		-h) HELPFLAG=1;; 
		*) echo "$1 is an illegal argument"
		   exit 1;;
 	esac
 	shift   # next flag
 done

 shift   # skip --

 if [ $HELPFLAG -eq 1 ]
 then
 	print_help
 	exit 0
 elif [ $LISTFLAG -eq 1 ]
 then
 	list_sm_dir
 	exit 0
 elif [ $SOURCEFLAG -ne 1 ] || [ $MODULEFLAG -ne 1 ]
 then
 	echo "-m and -s arguments must both be used at the same time"
 	exit 1
 fi

 # make sure that kernel source and module directories exist

 if [ ! -d /lib/modules/${MODULEDIR} ]
 then
 	echo "/lib/modules/${MODULEDIR} does not exist"
 	exit 1
 fi

 if [ ! -d /usr/src/${SOURCEDIR} ]
 then
	 echo "/usr/src/${SOURCEDIR} doesn't not exist"
	 exit 1
 fi
else
 USEARGS=0 # don't use any arguments to scripts
fi

EXEDIR="/opt/hp/src/hp_qla2x00src"
cd $EXEDIR

if [ $? -ne 0 ]
then
 exit 1
fi

# build driver from source code

if [ $USEARGS -eq 0 ]
then
 ./build_driver
else
 ./build_driver -m $MODULEDIR -s $SOURCEDIR
fi

if [ $? -ne 0 ]
then
 exit 1
fi

# edit necessary configuration files

echo ""
./edit_conf

# create new ramdisk image

echo ""

if [ $USEARGS -eq 0 ]
then
 ./make_initrd
else
 ./make_initrd $MODULEDIR
fi

